@@ -4,7 +4,7 @@ use strict;
 
 use Scalar::Util;
 use vars qw ($VERSION @ISA @REGEXS);
-$VERSION = 0.662;
+$VERSION = 0.67;
 
 push @REGEXS, qr/
 	^v?	# optional leading 'v'
@@ -43,6 +43,12 @@ sub new
 		$value = $tvalue;
 	    }
 	}
+
+	# exponential notation
+	if ( $value =~ /\d+e-?\d+/ ) {
+	    $value = sprintf("%.9f",$value);
+	    $value =~ s/(0+)$//;
+	}
 	
 	# This is not very efficient, but it is morally equivalent
 	# to the XS code (as that is the reference implementation).
@@ -363,11 +369,6 @@ sub is_alpha {
 sub qv {
     my ($value) = @_;
 
-    if ( $value =~ /\d+e-?\d+/ ) { # exponential notation
-	$value = sprintf("%.9f",$value);
-	$value =~ s/(0+)//;
-    }
-
     my $eval = eval 'Scalar::Util::isvstring($value)';
     if ( !$@ and $eval ) {
 	$value = sprintf("v%vd",$value);
@@ -409,10 +410,6 @@ sub _verify {
 	}
 
 	if ( defined $req ) {
-	    if ( $req =~ /\d+e-?\d+/ ) { # exponential notation
-		$req = sprintf("%.9f",$req);
-		$req =~ s/(0+)$//;
-	    }
 	    unless ( defined $version ) {
 		my $msg =  "$class does not define ".
 			   "\$$class\::VERSION--version check failed";
